powered by
Checks whether an R object is of deadata class or not.
is.deadata(x)
Any R object.
Returns TRUE if its argument is a deadata object (that is, has "deadata" amongst its classes) and FALSE otherwise.
TRUE
FALSE