Range directional model from Portela et al. (2004).
model_rdm(datadea,
dmu_eval = NULL,
dmu_ref = NULL,
orientation = c("no", "io", "oo"),
irdm = FALSE,
maxslack = TRUE,
weight_slack_i = 1,
weight_slack_o = 1,
compute_target = TRUE,
returnlp = FALSE,
...)The data, including n DMUs, m inputs and s outputs.
A numeric vector containing which DMUs have to be evaluated.
If NULL (default), all DMUs are considered.
A numeric vector containing which DMUs are the evaluation reference set.
If NULL (default), all DMUs are considered.
A string, equal to "no" (non-oriented), "io" (input oriented), or "oo" (output oriented).
Logical. If it is TRUE, it applies the IRDM (inverse range directional model).
Logical. If it is TRUE, it computes the max slack solution.
A value, vector of length m, or matrix m x ne (where ne is the lenght of dmu_eval)
with the weights of the input slacks for the max slack solution.
A value, vector of length s, or matrix s x ne (where ne is the lenght of dmu_eval)
with the weights of the output slacks for the max slack solution.
Logical. If it is TRUE, it computes targets of the max slack solution.
Logical. If it is TRUE, it returns the linear problems (objective function and constraints) of stage 1.
Ignored, for compatibility issues.
Portela, M.; Thanassoulis, E.; Simpson, G. (2004). "Negative data in DEA: a directional distance approach applied to bank branches", Journal of the Operational Research Society, 55 1111-1121.