Learn R Programming

deaR (version 1.0)

model_sbmeff: Slack based measure (SBM) of efficiency model.

Description

Calculate the SBM model proposed by Tone (2001).

Usage

model_sbmeff(datadea,
            dmu_eval = NULL,
            dmu_ref = NULL,
            weight_input = 1,
            weight_output = 1,
            orientation = c("no", "io", "oo"),
            rts = c("crs", "vrs", "nirs", "ndrs", "grs"),
            L = 1,
            U = 1,
            compute_target = TRUE,
            returnlp = FALSE,
            ...)

Arguments

datadea

The data, including n DMUs, m inputs and s outputs.

dmu_eval

A numeric vector containing which DMUs have to be evaluated.

dmu_ref

A numeric vector containing which DMUs are the evaluation reference set.

weight_input

A value, vector of length m, or matrix m x ne (where ne is the lenght of dmu_eval) with weights to inputs corresponding to the relative importance of items.

weight_output

A value, vector of length m, or matrix m x ne (where ne is the lenght of dmu_eval) with weights to outputs corresponding to the relative importance of items.

orientation

A string, equal to "no" (non-oriented), "io" (input-oriented) or "oo" (output-oriented).

rts

A string, determining the type of returns to scale, equal to "crs" (constant), "vrs" (variable), "nirs" (non-increasing), "ndrs" (non-decreasing) or "grs" (generalized).

L

Lower bound for the generalized returns to scale (grs).

U

Upper bound for the generalized returns to scale (grs).

compute_target

Logical. If it is TRUE, it computes targets.

returnlp

Logical. If it is TRUE, it returns the linear problems (objective function and constraints).

...

Other options (currently not implemented)

References

Tone, K. (2001). "A Slacks-Based Beasure of Efficiency in Data Envelopment Analysis", European Journal of Operational Research, 130, 498-509. https://doi.org/10.1016/S0377-2217(99)00407-5

Cooper, W.W.; Seiford, L.M.; Tone, K. (2007). Data Envelopment Analysis. A Comprehensive Text with Models, Applications, References and DEA-Solver Software. 2nd Edition. Springer, New York. https://doi.org/10.1007/978-0-387-45283-8

See Also

model_nonradial, model_deaps, model_deaps, model_sbmsupereff

Examples

Run this code
# NOT RUN {
# Replication of results in Tone (2001, p.505)
data("Tone2001")
data_example <- read_data(Tone2001, 
                          ni = 2, 
                          no = 2)
result_SBM <- model_sbmeff(data_example, 
                           orientation = "no", 
                           rts = "crs")
result_CCR <- model_basic(data_example, 
                          orientation = "io", 
                          rts = "crs")
efficiencies(result_SBM)
efficiencies(result_CCR)
slacks(result_SBM)
slacks(result_CCR)
 
# }

Run the code above in your browser using DataLab