Learn R Programming

deaR (version 1.2.1)

modelfuzzy_kaoliu: Fuzzy DEA model.

Description

Solve the fuzzy DEA model by Kao and Liu (2000)

Usage

modelfuzzy_kaoliu(datadea,
                  dmu_eval = NULL,
                  kaoliu_modelname = c("basic", "additive", "addsupereff", 
                                       "deaps", "fdh", "multiplier", "nonradial",
                                       "sbmeff", "sbmsupereff", "supereff"),
                  alpha = 1,
                  ...)

Arguments

datadea

The data, including DMUs, inputs and outputs.

dmu_eval

A numeric vector containing which DMUs have to be evaluated. If NULL (default), all DMUs are considered.

kaoliu_modelname

a string containing the name of the model.

alpha

A numeric vector with the alpha-cuts (in [0,1]). If alpha>1, it determines the number of alpha-cuts, equispatially distributed in [0,1].

...

dmu_ref, orientation, rts and other model parameters.

Value

An object of class deadata_fuzzy.

References

Bosc<U+00E1>, J.E.; Liern, V.; Sala, R.; Mart<U+00ED>nez, A. (2011). "Ranking Decision Making Units by Means of Soft Computing DEA Models". International Journal of Uncertainty, Fuzziness and Knowledge-Based Systems, 19(1), p.115-134.

Emrouznejad, A.; Tavana, M.; Hatami-Marbini, A. (2014). <U+201C>The State of the Art in Fuzzy Data Envelopment Analysis<U+201D>, in A. Emrouznejad and M. Tavana (eds.), Performance Measurement with Fuzzy Data Envelopment Analysis. Studies in Fuzziness and Soft Computing 309. Springer, Berlin.

Hatami-Marbini, A.; Emrouznejad, A.; Tavana, M. (2011). "A Taxonomy and Review of the Fuzzy Data Envelopment Analysis Literature: Two Decades in the Making", European Journal of Operational Research, 214, 457<U+2013>472.

Kao, C.; Liu, S.T. (2000). <U+201C>Fuzzy efficiency measures in data envelopment analysis, Fuzzy Sets and Systems<U+201D>, 119, 149<U+2013>160.

Kao, C., Liu, S.T., (2000). <U+201C>Data envelopment analysis with missing data: An application to university libraries in Taiwan<U+201D>, Journal of the Operational Research Society, 51, 897<U+2013>905.

Kao, C., Liu, S.T. (2003). <U+201C>A mathematical programming approach to fuzzy efficiency ranking<U+201D>, International Journal of Production Economics, 85.

See Also

model_basic, model_multiplier, modelfuzzy_possibilistic, modelfuzzy_guotanaka

Examples

Run this code
# NOT RUN {
# Example 1. 
# Replication of results in Bosc<U+00C3><U+00A1>, Liern, Sala and Mart<U+00C3><U+00AD>nez (2011, p.125)
data("Leon2003")
data_example <- read_data_fuzzy(datadea = Leon2003,
                                inputs.mL = 2, 
                                inputs.dL = 3, 
                                outputs.mL = 4, 
                                outputs.dL = 5)
result <- modelfuzzy_kaoliu(data_example,
                            kaoliu_modelname = "basic", 
                            alpha = seq(0, 1, by = 0.1), 
                            orientation = "io", 
                            rts = "vrs")
efficiencies(result)

# Example 2.
# Replication of results in Kao and Liu (2003, p.152)
data("Kao_Liu_2003")
data_example <- read_data_fuzzy(Kao_Liu_2003, 
                                inputs.mL = 2, 
                                outputs.mL = 3:7, 
                                outputs.dL = c(NA, NA, 8, NA, 10),
                                outputs.dR = c(NA, NA, 9, NA, 11))
result <- modelfuzzy_kaoliu(data_example, 
                            kaoliu_modelname = "basic", 
                            orientation = "oo", 
                            rts = "vrs", 
                            alpha = 0)
sol <- efficiencies(result)
eff <- data.frame(1 / sol$Worst, 1 / sol$Best)
names(eff) <- c("eff_lower", "eff_upper")
eff

# }

Run the code above in your browser using DataLab