Learn R Programming

deaR (version 1.2.1)

modelfuzzy_possibilistic: Possibilistic Fuzzy DEA model.

Description

Solve the possibilistic fuzzy DEA model proposed by Le<U+00F3>n et. al (2003).

Usage

modelfuzzy_possibilistic(datadea,
                         dmu_eval = NULL,
                         poss_modelname = c("basic"),
                         h = 1,
                         ...)

Arguments

datadea

The data, including DMUs, inputs and outputs.

dmu_eval

A numeric vector containing which DMUs have to be evaluated. If NULL (default), all DMUs are considered.

poss_modelname

a string containing the name of the model.

h

A numeric vector with the h-levels (in [0,1]).

...

dmu_ref, orientation, rts and other model parameters.

Value

An object of class deadata_fuzzy.

References

Emrouznejad, A.; Tavana, M.; Hatami-Marbini, A. (2014). <U+201C>The State of the Art in Fuzzy Data Envelopment Analysis<U+201D>, in A. Emrouznejad and M. Tavana (eds.), Performance Measurement with Fuzzy Data Envelopment Analysis. Studies in Fuzziness and Soft Computing 309. Springer, Berlin. https://doi.org/10.1007/978-3-642-41372-8_1

Hatami-Marbini, A.; Emrouznejad, A.; Tavana, M. (2011). "A Taxonomy and Review of the Fuzzy Data Envelopment Analysis Literature: Two Decades in the Making", European Journal of Operational Research, 214, 457<U+2013>472. https://doi.org/10.1016/j.ejor.2011.02.001

L<U+00E9>on, T.; Liern, V. Ruiz, J.; Sirvent, I. (2003). "A Possibilistic Programming Approach to the Assessment of Efficiency with DEA Models", Fuzzy Sets and Systems, 139, 407<U+2013>419. https://doi.org/10.1016/S0165-0114(02)00608-5

See Also

model_basic, modelfuzzy_kaoliu, modelfuzzy_guotanaka

Examples

Run this code
# NOT RUN {
# Replication of results in Leon et. al (2003, p. 416)
data("Leon2003")
data_example <- read_data_fuzzy(Leon2003,
                                inputs.mL = 2, 
                                inputs.dL = 3, 
                                outputs.mL = 4, 
                                outputs.dL = 5)
result <- modelfuzzy_possibilistic(data_example, 
                                   h = seq(0, 1, by = 0.1), 
                                   orientation = "io", 
                                   rts = "vrs")
efficiencies(result)
 
# }

Run the code above in your browser using DataLab