Learn R Programming

deaR (version 1.2.1)

undesirable_basic: Undesirable inputs and outputs for basic DEA model.

Description

This function transforms a deadata or deadata_fuzzy class with inputs and outputs into a deadata or deadata_fuzzy class with good inputs and/or outputs, and bad (undesirable) inputs and/or outputs. Onwards, it is recommended to use a dea model with variable returns to scale (vrs).

Usage

undesirable_basic(datadea,
                  vtrans_i = NULL,
                  vtrans_o = NULL)

Arguments

datadea

The data, including DMUs, inputs and outputs.

vtrans_i

Numeric vector of translation for undesirable inputs. If vtrans_i[i] is NA, then it applies the "max + 1" translation to the i-th undesirable input. If vtrans_i is a constant, then it applies the same translation to all undesirable inputs. If vtrans_i is NULL, then it applies the "max + 1" translation to all undesirable inputs.

vtrans_o

Numeric vector of translation for undesirable outputs, analogous to vtrans_i, but applied to outputs.

Value

An object of class deadata or deadata_fuzzy.

Examples

Run this code
# NOT RUN {
data("Hua_Bian_2007")
# The third output is an undesirable output.
data_example <- read_data(Hua_Bian_2007,
                          ni = 2, 
                          no = 3, 
                          ud_outputs = 3) 
# rts must be "vrs" for undesirable inputs/outputs:
# Translation parameter is set to (max + 1)
result <- model_basic(data_example,
                      orientation = "oo", 
                      rts = "vrs") 

# }

Run the code above in your browser using DataLab