powered by
Checks whether an R object is of dea class or not.
is.dea(x)
Any R object.
Returns TRUE if its argument is a dea object (that is, has "dea" amongst its classes) and FALSE otherwise.
TRUE
FALSE