Learn R Programming

deaR (version 1.0)

is.dea: dea class check.

Description

Checks wether an R object is of dea class or not.

Usage

is.dea(x)

Arguments

x

Any R object.

Value

Returns TRUE if its argument is a dea object (that is, has "dea" amongst its classes) and FALSE otherwise.