Learn R Programming

deaR (version 1.0)

plot.dea: Plot for DEA models.

Description

Plot some attribute of a DEA model (conventional, fuzzy or Malmquist).

Usage

# S3 method for dea
plot(x, ...)

Arguments

x

An object of class "dea" obtained by a dea model function.

...

Ignored, for compatibility issues.

Value

Depending on the model it returns a single data.frame containing: efficiencies, slacks, lambdas, targets, references or a list of data.frames with the cross-efficiencies computed with different methods (Arbitrary, Method II or Method III (see CITA)) or, in case the model is a malmquist index, a single data.frame with the coefficients for the different periods.

References

#' Zhu, J. (2014). Quantitative Models for Performance Evaluation and Benchmarking. Data Envelopment Analysis with Spreadsheets. 3rd Edition Springer, New York. DOI: 10.1007/978-3-319-06647-9

Examples

Run this code
# NOT RUN {
data_example <- read_data(datadea = Fortune500,
                          dmus = 1,
                          inputs = 2:4, 
                          outputs = 5:6)
result <- model_basic(data_example)
plot(result)

# }

Run the code above in your browser using DataLab